# Module 'eosclient'

This module configures an EOS client and supports SLC6 and CC7. The
module can optionally FUSE mount /eos and hook krb5 credentials to PAM.

Regarding FUSE mounts, the module supports two versions of the eos-fuse
mounts: the "legacy" `eosd` and "new" `eosxd`. The choice between `eosd`
and `eosxd` is not customizable per EOS instance: the required version
is enforced by the `eosclient::eosxd_ready` variable.

*Note* that this module does not presently support `eosxd` mounts
without `eosclient::enable_autofs: true`.

## Basic Usage:

To install the EOS client RPMs (and not configure any /eos mounts):

```puppet
include eosclient
```

## Configuring /eos mounts:

To configure and enable /eos mounts use yaml:

```YAML
---
eosclient::enable_fuse: true
```

Optionally enable PAM/sshd to acquire EOS FUSE credentials on login with
the ``enable_pam_hook`` param.

To specify which EOS instances to mount, set the ``mounts`` to a list of
valid EOS instance names, e.g. ``['user','atlas']``. The default value
of the ``mounts`` param lets you specify this via a hiera array called
``eos_mounts``.

## Parameters to Eosclient Class
 * `enable_fuse` enable the /eos FUSE mounts. Defaults to `false`.
 * `enable_pam_hook` enable a PAM hook to link krb5 creditials to EOS at
   login time. Useful for AFS-like behaviour on interactive machines.
   Defaults to `false`.
 * `enable_autofs` Mount /eos with autofs instead of the eosd service.
   Defaults to `false`.
 * `mounts` array of EOS instances to mount. Defaults to
   `hiera(eos_mounts, [])`.
 * `yum_priority` priority of the eos yum repos. Defaults to `9`.
 * `manage_autofs_service` Whether or not this module should manage the
   puppet `Service['autofs']`. Set to `false` if the service is managed
   elsewhere. Defaults to `true`.
 * `manage_autofs_rpm` Whether or not to install the `autofs` package in
   this module. Set to `false` if the package is managed elsewhere, for
   example by the `autofs` module. Defaults to `true`.
 * `fuse_logrotate_days` Keep this many days of logs in
   `/var/log/eos/fuse/`. Defaults to `7`.
 * `enable_lemon` Boolean, defaults to `true`, if `true` lemon metrics
   for eos will be enabled.
 * `version` which version to install. Defaults to `present`, the latest
   available version. It is not advised to use this option unless
   directed to by the EOS team.

Puppet databindings allow all the above settings to be set via hiera:

```yaml
---
eosclient::enable_fuse: true
eosclient::enable_pam_hook: true
```

## /eos Configuration Options (FUSEX)
This module uses the default eosxd configution options, documented here:
https://gitlab.cern.ch/dss/eos/blob/master/fusex/README.md

If you would like to override a setting for *all* eosxd mounts on your
system, create a hiera hash called `eosclient::common_config`. For
example, custom cache options may be configured as follows:

```yaml
---
eosclient::common_config:
  conf:
    cache:
      size-mb: 1024
```

You are also able to override settings for a subset of eos mounts with
the following syntax:

```yaml
---
eosclient::instance_config:
  home-a:
    conf:
      cache:
        size-mb: 1024
```

## Deprecations
Three hiera variables are deprecated but still work. Please migrate.
* `eos_mounts` becomes `eosclient::mounts`
* `eosclient_instance_config` becomes `eosclient::instance_config`.
* `eosclient_custom_config` becomes `eosclient::common_config`.

Two hiera variables are deprecated and will cause a failiure if they are
set.
* `eosclient_common_config` becomes `eosclient::common_config`.
* `eosclient_eosxd_ready_instances` becomes `eosclient::eosxd_ready`.


## /eos Configuration Options (Legacy)
This module provides sensible defaults for the /eos mounts. If you would
like to override a setting for *all* eos mounts on your system, create a
hiera hash called `eosclient::common_config` and add your key/value
config pairs. For example, to disable the KRB5 feature, put this in
hiera:

```yaml
---
eosclient::common_config:
  EOS_FUSE_USER_KRB5CC: 0
```

You are also able to override settings for a subset of eos mounts with
the following syntax:

```yaml
---
eosclient::instance_config:
  user:
    EOS_FUSE_MGM_ALIAS: eosuser-web.cern.ch
  project:
    EOS_FUSE_MGM_ALIAS: eosuser-web.cern.ch
```

## Example: Basic Usage
Here is an example usage of this module. The example would be useful for
an interactive login client which mounts eosuser and eoscms , and also
allocates more than the default for a fuse cache:

```puppet
include eosclient
```

```yaml
---
eosclient::enable_fuse: true
eosclient::enable_pam_hook: true
eosclient::mounts:
  - user
  - cms
eosclient::common_config:
  EOS_FUSE_CACHE_SIZE: 134217728
```

## Example: Auto-mounted /eos (like on lxplus)
This example shows how to setup the module with auto-mounted /eos, like
it is done on lxplus.

```puppet
include eosclient
```

```yaml
---
eosclient::enable_fuse: true
eosclient::enable_pam_hook: true
eosclient::enable_autofs: true

eosclient::mounts:
  - ams
  - experiment
  - project
  - user
  - workspace
```
